import type { HtmlTags } from "html-tags";
import type { StyleValue } from "@webstudio-is/css-engine";

export const html: Map<`${HtmlTags}:${string}`, StyleValue> = new Map([
  ["article:display", { type: "keyword", value: "block" }],
  ["aside:display", { type: "keyword", value: "block" }],
  ["details:display", { type: "keyword", value: "block" }],
  ["div:display", { type: "keyword", value: "block" }],
  ["dt:display", { type: "keyword", value: "block" }],
  ["figcaption:display", { type: "keyword", value: "block" }],
  ["footer:display", { type: "keyword", value: "block" }],
  ["form:display", { type: "keyword", value: "block" }],
  ["header:display", { type: "keyword", value: "block" }],
  ["hgroup:display", { type: "keyword", value: "block" }],
  ["html:display", { type: "keyword", value: "block" }],
  ["main:display", { type: "keyword", value: "block" }],
  ["nav:display", { type: "keyword", value: "block" }],
  ["section:display", { type: "keyword", value: "block" }],
  ["summary:display", { type: "keyword", value: "block" }],
  ["body:display", { type: "keyword", value: "block" }],
  ["body:marginTop", { type: "unit", unit: "px", value: 8 }],
  ["body:marginRight", { type: "unit", unit: "px", value: 8 }],
  ["body:marginBottom", { type: "unit", unit: "px", value: 8 }],
  ["body:marginLeft", { type: "unit", unit: "px", value: 8 }],
  ["p:display", { type: "keyword", value: "block" }],
  ["dl:display", { type: "keyword", value: "block" }],
  ["p:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["dl:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["p:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["dl:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["dd:display", { type: "keyword", value: "block" }],
  ["dd:marginLeft", { type: "unit", unit: "px", value: 40 }],
  ["blockquote:display", { type: "keyword", value: "block" }],
  ["figure:display", { type: "keyword", value: "block" }],
  ["blockquote:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["blockquote:marginRight", { type: "unit", unit: "px", value: 40 }],
  ["blockquote:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["blockquote:marginLeft", { type: "unit", unit: "px", value: 40 }],
  ["figure:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["figure:marginRight", { type: "unit", unit: "px", value: 40 }],
  ["figure:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["figure:marginLeft", { type: "unit", unit: "px", value: 40 }],
  ["address:display", { type: "keyword", value: "block" }],
  ["address:fontStyle", { type: "keyword", value: "italic" }],
  ["h1:display", { type: "keyword", value: "block" }],
  ["h1:fontWeight", { type: "keyword", value: "bold" }],
  ["h1:fontSize", { type: "unit", unit: "em", value: 2 }],
  ["h1:marginTop", { type: "unit", unit: "em", value: 0.67 }],
  ["h1:marginBottom", { type: "unit", unit: "em", value: 0.67 }],
  ["h2:display", { type: "keyword", value: "block" }],
  ["h2:fontWeight", { type: "keyword", value: "bold" }],
  ["h2:fontSize", { type: "unit", unit: "em", value: 1.5 }],
  ["h2:marginTop", { type: "unit", unit: "em", value: 0.83 }],
  ["h2:marginBottom", { type: "unit", unit: "em", value: 0.83 }],
  ["h3:display", { type: "keyword", value: "block" }],
  ["h3:fontWeight", { type: "keyword", value: "bold" }],
  ["h3:fontSize", { type: "unit", unit: "em", value: 1.17 }],
  ["h3:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["h3:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["h4:display", { type: "keyword", value: "block" }],
  ["h4:fontWeight", { type: "keyword", value: "bold" }],
  ["h4:marginTop", { type: "unit", unit: "em", value: 1.33 }],
  ["h4:marginBottom", { type: "unit", unit: "em", value: 1.33 }],
  ["h5:display", { type: "keyword", value: "block" }],
  ["h5:fontWeight", { type: "keyword", value: "bold" }],
  ["h5:fontSize", { type: "unit", unit: "em", value: 0.83 }],
  ["h5:marginTop", { type: "unit", unit: "em", value: 1.67 }],
  ["h5:marginBottom", { type: "unit", unit: "em", value: 1.67 }],
  ["h6:display", { type: "keyword", value: "block" }],
  ["h6:fontWeight", { type: "keyword", value: "bold" }],
  ["h6:fontSize", { type: "unit", unit: "em", value: 0.67 }],
  ["h6:marginTop", { type: "unit", unit: "em", value: 2.33 }],
  ["h6:marginBottom", { type: "unit", unit: "em", value: 2.33 }],
  ["pre:display", { type: "keyword", value: "block" }],
  ["pre:whiteSpaceCollapse", { type: "keyword", value: "preserve" }],
  ["pre:textWrapMode", { type: "keyword", value: "nowrap" }],
  ["pre:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["pre:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["table:display", { type: "keyword", value: "table" }],
  ["table:borderSpacing", { type: "unit", unit: "px", value: 2 }],
  ["table:borderCollapse", { type: "keyword", value: "separate" }],
  ["table:boxSizing", { type: "keyword", value: "border-box" }],
  ["table:textIndent", { type: "unit", unit: "number", value: 0 }],
  ["caption:display", { type: "keyword", value: "table-caption" }],
  ["caption:textAlign", { type: "keyword", value: "center" }],
  ["tr:display", { type: "keyword", value: "table-row" }],
  ["tr:verticalAlign", { type: "keyword", value: "inherit" }],
  ["col:display", { type: "keyword", value: "table-column" }],
  ["colgroup:display", { type: "keyword", value: "table-column-group" }],
  ["tbody:display", { type: "keyword", value: "table-row-group" }],
  ["tbody:verticalAlign", { type: "keyword", value: "middle" }],
  ["thead:display", { type: "keyword", value: "table-header-group" }],
  ["thead:verticalAlign", { type: "keyword", value: "middle" }],
  ["tfoot:display", { type: "keyword", value: "table-footer-group" }],
  ["tfoot:verticalAlign", { type: "keyword", value: "middle" }],
  ["td:display", { type: "keyword", value: "table-cell" }],
  ["td:verticalAlign", { type: "keyword", value: "inherit" }],
  ["td:paddingTop", { type: "unit", unit: "px", value: 1 }],
  ["td:paddingRight", { type: "unit", unit: "px", value: 1 }],
  ["td:paddingBottom", { type: "unit", unit: "px", value: 1 }],
  ["td:paddingLeft", { type: "unit", unit: "px", value: 1 }],
  ["th:display", { type: "keyword", value: "table-cell" }],
  ["th:verticalAlign", { type: "keyword", value: "inherit" }],
  ["th:fontWeight", { type: "keyword", value: "bold" }],
  ["th:paddingTop", { type: "unit", unit: "px", value: 1 }],
  ["th:paddingRight", { type: "unit", unit: "px", value: 1 }],
  ["th:paddingBottom", { type: "unit", unit: "px", value: 1 }],
  ["th:paddingLeft", { type: "unit", unit: "px", value: 1 }],
  ["b:fontWeight", { type: "keyword", value: "bold" }],
  ["strong:fontWeight", { type: "keyword", value: "bold" }],
  ["i:fontStyle", { type: "keyword", value: "italic" }],
  ["cite:fontStyle", { type: "keyword", value: "italic" }],
  ["em:fontStyle", { type: "keyword", value: "italic" }],
  ["var:fontStyle", { type: "keyword", value: "italic" }],
  ["dfn:fontStyle", { type: "keyword", value: "italic" }],
  ["code:fontFamily", { type: "fontFamily", value: ["monospace"] }],
  ["kbd:fontFamily", { type: "fontFamily", value: ["monospace"] }],
  ["samp:fontFamily", { type: "fontFamily", value: ["monospace"] }],
  ["mark:backgroundColor", { type: "keyword", value: "yellow" }],
  ["mark:color", { type: "keyword", value: "black" }],
  ["u:textDecorationLine", { type: "keyword", value: "underline" }],
  ["ins:textDecorationLine", { type: "keyword", value: "underline" }],
  ["s:textDecorationLine", { type: "keyword", value: "line-through" }],
  ["del:textDecorationLine", { type: "keyword", value: "line-through" }],
  ["sub:verticalAlign", { type: "keyword", value: "sub" }],
  ["sub:fontSize", { type: "keyword", value: "smaller" }],
  ["sup:verticalAlign", { type: "keyword", value: "super" }],
  ["sup:fontSize", { type: "keyword", value: "smaller" }],
  ["a:textDecorationLine", { type: "keyword", value: "underline" }],
  ["a:cursor", { type: "keyword", value: "pointer" }],
  ["a:color", { type: "rgb", alpha: 1, r: 0, g: 0, b: 238 }],
  ["ul:display", { type: "keyword", value: "block" }],
  ["ul:listStyleType", { type: "keyword", value: "disc" }],
  ["ul:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["ul:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["ul:paddingLeft", { type: "unit", unit: "px", value: 40 }],
  ["ol:display", { type: "keyword", value: "block" }],
  ["ol:listStyleType", { type: "keyword", value: "decimal" }],
  ["ol:marginTop", { type: "unit", unit: "em", value: 1 }],
  ["ol:marginBottom", { type: "unit", unit: "em", value: 1 }],
  ["ol:paddingLeft", { type: "unit", unit: "px", value: 40 }],
  ["li:display", { type: "keyword", value: "list-item" }],
  ["li:textAlign", { type: "keyword", value: "match-parent" }],
  ["hr:color", { type: "keyword", value: "gray" }],
  ["hr:borderTopWidth", { type: "unit", unit: "px", value: 1 }],
  ["hr:borderRightWidth", { type: "unit", unit: "px", value: 1 }],
  ["hr:borderBottomWidth", { type: "unit", unit: "px", value: 1 }],
  ["hr:borderLeftWidth", { type: "unit", unit: "px", value: 1 }],
  ["hr:borderTopStyle", { type: "keyword", value: "solid" }],
  ["hr:borderRightStyle", { type: "keyword", value: "solid" }],
  ["hr:borderBottomStyle", { type: "keyword", value: "solid" }],
  ["hr:borderLeftStyle", { type: "keyword", value: "solid" }],
  ["hr:marginTop", { type: "unit", unit: "em", value: 0.5 }],
  ["hr:marginRight", { type: "keyword", value: "auto" }],
  ["hr:marginBottom", { type: "unit", unit: "em", value: 0.5 }],
  ["hr:marginLeft", { type: "keyword", value: "auto" }],
  ["hr:overflowX", { type: "keyword", value: "hidden" }],
  ["hr:overflowY", { type: "keyword", value: "hidden" }],
  ["hr:display", { type: "keyword", value: "block" }],
  ["legend:display", { type: "keyword", value: "block" }],
  ["legend:paddingLeft", { type: "unit", unit: "px", value: 2 }],
  ["legend:paddingRight", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:display", { type: "keyword", value: "block" }],
  ["fieldset:marginLeft", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:marginRight", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:paddingTop", { type: "unit", unit: "em", value: 0.35 }],
  ["fieldset:paddingRight", { type: "unit", unit: "em", value: 0.75 }],
  ["fieldset:paddingBottom", { type: "unit", unit: "em", value: 0.625 }],
  ["fieldset:paddingLeft", { type: "unit", unit: "em", value: 0.75 }],
  ["fieldset:borderTopWidth", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:borderRightWidth", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:borderBottomWidth", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:borderLeftWidth", { type: "unit", unit: "px", value: 2 }],
  ["fieldset:borderTopStyle", { type: "keyword", value: "solid" }],
  ["fieldset:borderRightStyle", { type: "keyword", value: "solid" }],
  ["fieldset:borderBottomStyle", { type: "keyword", value: "solid" }],
  ["fieldset:borderLeftStyle", { type: "keyword", value: "solid" }],
  ["fieldset:borderTopColor", { type: "keyword", value: "lightgray" }],
  ["fieldset:borderRightColor", { type: "keyword", value: "lightgray" }],
  ["fieldset:borderBottomColor", { type: "keyword", value: "lightgray" }],
  ["fieldset:borderLeftColor", { type: "keyword", value: "lightgray" }],
  ["fieldset:minWidth", { type: "keyword", value: "min-content" }],
  ["label:cursor", { type: "keyword", value: "default" }],
  ["input:appearance", { type: "keyword", value: "auto" }],
  ["input:paddingTop", { type: "unit", unit: "px", value: 1 }],
  ["input:paddingRight", { type: "unit", unit: "px", value: 1 }],
  ["input:paddingBottom", { type: "unit", unit: "px", value: 1 }],
  ["input:paddingLeft", { type: "unit", unit: "px", value: 1 }],
  ["input:borderTopWidth", { type: "unit", unit: "px", value: 2 }],
  ["input:borderRightWidth", { type: "unit", unit: "px", value: 2 }],
  ["input:borderBottomWidth", { type: "unit", unit: "px", value: 2 }],
  ["input:borderLeftWidth", { type: "unit", unit: "px", value: 2 }],
  ["input:borderTopStyle", { type: "keyword", value: "solid" }],
  ["input:borderRightStyle", { type: "keyword", value: "solid" }],
  ["input:borderBottomStyle", { type: "keyword", value: "solid" }],
  ["input:borderLeftStyle", { type: "keyword", value: "solid" }],
  ["input:backgroundColor", { type: "keyword", value: "white" }],
  ["input:cursor", { type: "keyword", value: "text" }],
  ["textarea:color", { type: "keyword", value: "initial" }],
  ["select:color", { type: "keyword", value: "initial" }],
  ["button:color", { type: "keyword", value: "initial" }],
  ["textarea:letterSpacing", { type: "keyword", value: "normal" }],
  ["select:letterSpacing", { type: "keyword", value: "normal" }],
  ["button:letterSpacing", { type: "keyword", value: "normal" }],
  ["textarea:wordSpacing", { type: "keyword", value: "normal" }],
  ["select:wordSpacing", { type: "keyword", value: "normal" }],
  ["button:wordSpacing", { type: "keyword", value: "normal" }],
  ["textarea:lineHeight", { type: "keyword", value: "normal" }],
  ["select:lineHeight", { type: "keyword", value: "normal" }],
  ["button:lineHeight", { type: "keyword", value: "normal" }],
  ["textarea:textTransform", { type: "keyword", value: "none" }],
  ["select:textTransform", { type: "keyword", value: "none" }],
  ["button:textTransform", { type: "keyword", value: "none" }],
  ["textarea:textIndent", { type: "unit", unit: "number", value: 0 }],
  ["select:textIndent", { type: "unit", unit: "number", value: 0 }],
  ["button:textIndent", { type: "unit", unit: "number", value: 0 }],
  [
    "textarea:textShadow",
    {
      type: "layers",
      value: [{ type: "tuple", value: [{ type: "keyword", value: "none" }] }],
    },
  ],
  [
    "select:textShadow",
    {
      type: "layers",
      value: [{ type: "tuple", value: [{ type: "keyword", value: "none" }] }],
    },
  ],
  [
    "button:textShadow",
    {
      type: "layers",
      value: [{ type: "tuple", value: [{ type: "keyword", value: "none" }] }],
    },
  ],
  ["textarea:display", { type: "keyword", value: "inline-block" }],
  ["select:display", { type: "keyword", value: "inline-block" }],
  ["button:display", { type: "keyword", value: "inline-block" }],
  ["textarea:textAlign", { type: "keyword", value: "start" }],
  ["textarea:appearance", { type: "keyword", value: "auto" }],
  ["textarea:marginTop", { type: "unit", unit: "px", value: 1 }],
  ["textarea:marginBottom", { type: "unit", unit: "px", value: 1 }],
  ["textarea:borderTopWidth", { type: "unit", unit: "px", value: 1 }],
  ["textarea:borderRightWidth", { type: "unit", unit: "px", value: 1 }],
  ["textarea:borderBottomWidth", { type: "unit", unit: "px", value: 1 }],
  ["textarea:borderLeftWidth", { type: "unit", unit: "px", value: 1 }],
  ["textarea:borderTopStyle", { type: "keyword", value: "solid" }],
  ["textarea:borderRightStyle", { type: "keyword", value: "solid" }],
  ["textarea:borderBottomStyle", { type: "keyword", value: "solid" }],
  ["textarea:borderLeftStyle", { type: "keyword", value: "solid" }],
  ["textarea:paddingTop", { type: "unit", unit: "px", value: 2 }],
  ["textarea:paddingRight", { type: "unit", unit: "px", value: 2 }],
  ["textarea:paddingBottom", { type: "unit", unit: "px", value: 2 }],
  ["textarea:paddingLeft", { type: "unit", unit: "px", value: 2 }],
  ["textarea:backgroundColor", { type: "keyword", value: "white" }],
  ["textarea:verticalAlign", { type: "keyword", value: "text-bottom" }],
  ["textarea:cursor", { type: "keyword", value: "text" }],
  ["textarea:resize", { type: "keyword", value: "both" }],
  ["textarea:whiteSpaceCollapse", { type: "keyword", value: "preserve" }],
  ["textarea:textWrapMode", { type: "keyword", value: "wrap" }],
  ["textarea:wordWrap", { type: "keyword", value: "break-word" }],
  ["select:textAlign", { type: "keyword", value: "start" }],
  ["select:marginTop", { type: "unit", unit: "number", value: 0 }],
  ["select:marginRight", { type: "unit", unit: "number", value: 0 }],
  ["select:marginBottom", { type: "unit", unit: "number", value: 0 }],
  ["select:marginLeft", { type: "unit", unit: "number", value: 0 }],
  ["select:paddingTop", { type: "unit", unit: "px", value: 1 }],
  ["select:paddingRight", { type: "unit", unit: "px", value: 4 }],
  ["select:paddingBottom", { type: "unit", unit: "px", value: 1 }],
  ["select:paddingLeft", { type: "unit", unit: "px", value: 4 }],
  ["select:borderTopWidth", { type: "unit", unit: "px", value: 2 }],
  ["select:borderRightWidth", { type: "unit", unit: "px", value: 2 }],
  ["select:borderBottomWidth", { type: "unit", unit: "px", value: 2 }],
  ["select:borderLeftWidth", { type: "unit", unit: "px", value: 2 }],
  ["select:borderTopStyle", { type: "keyword", value: "solid" }],
  ["select:borderRightStyle", { type: "keyword", value: "solid" }],
  ["select:borderBottomStyle", { type: "keyword", value: "solid" }],
  ["select:borderLeftStyle", { type: "keyword", value: "solid" }],
  ["select:textWrapMode", { type: "keyword", value: "nowrap" }],
  ["select:wordWrap", { type: "keyword", value: "normal" }],
  ["select:cursor", { type: "keyword", value: "default" }],
  ["select:boxSizing", { type: "keyword", value: "border-box" }],
  ["select:userSelect", { type: "keyword", value: "none" }],
  ["select:overflowX", { type: "keyword", value: "clip" }],
  ["select:overflowY", { type: "keyword", value: "clip" }],
  ["select:verticalAlign", { type: "keyword", value: "baseline" }],
  ["select:appearance", { type: "keyword", value: "auto" }],
  ["option:display", { type: "keyword", value: "block" }],
  ["option:float", { type: "keyword", value: "none" }],
  ["option:position", { type: "keyword", value: "static" }],
  ["option:minHeight", { type: "unit", unit: "em", value: 1 }],
  ["option:paddingTop", { type: "unit", unit: "px", value: 2 }],
  ["option:paddingRight", { type: "unit", unit: "px", value: 2 }],
  ["option:paddingBottom", { type: "unit", unit: "px", value: 2 }],
  ["option:paddingLeft", { type: "unit", unit: "px", value: 4 }],
  ["option:userSelect", { type: "keyword", value: "none" }],
  ["option:textWrapMode", { type: "keyword", value: "nowrap" }],
  ["option:wordWrap", { type: "keyword", value: "normal" }],
  ["button:appearance", { type: "keyword", value: "auto" }],
  ["button:paddingTop", { type: "unit", unit: "px", value: 2 }],
  ["button:paddingRight", { type: "unit", unit: "px", value: 6 }],
  ["button:paddingBottom", { type: "unit", unit: "px", value: 3 }],
  ["button:paddingLeft", { type: "unit", unit: "px", value: 6 }],
  ["button:borderTopWidth", { type: "unit", unit: "px", value: 2 }],
  ["button:borderRightWidth", { type: "unit", unit: "px", value: 2 }],
  ["button:borderBottomWidth", { type: "unit", unit: "px", value: 2 }],
  ["button:borderLeftWidth", { type: "unit", unit: "px", value: 2 }],
  ["button:borderTopStyle", { type: "keyword", value: "solid" }],
  ["button:borderRightStyle", { type: "keyword", value: "solid" }],
  ["button:borderBottomStyle", { type: "keyword", value: "solid" }],
  ["button:borderLeftStyle", { type: "keyword", value: "solid" }],
  ["button:cursor", { type: "keyword", value: "default" }],
  ["button:boxSizing", { type: "keyword", value: "border-box" }],
  ["button:userSelect", { type: "keyword", value: "none" }],
  ["button:textAlign", { type: "keyword", value: "center" }],
  ["button:backgroundColor", { type: "keyword", value: "lightgray" }],
]);
